@@ -76,15 +76,12 @@
 #include "MagickCore/module.h"
 #include "MagickCore/utility.h"
 #if defined(MAGICKCORE_HEIC_DELEGATE)
-#if defined(MAGICKCORE_WINDOWS_SUPPORT) && !defined(__MINGW32__)
-#include <heif.h>
-#else
-#include <libheif/heif.h>
-#endif
-
 #define HEIC_COMPUTE_NUMERIC_VERSION(major,minor,patch) \
   ((major<<24) | (minor<<16) | (patch<<8) | 0)
-
+#include <libheif/heif.h>
+#if LIBHEIF_NUMERIC_VERSION >= HEIC_COMPUTE_NUMERIC_VERSION(1,17,0)
+#include <libheif/heif_properties.h>
+#endif
 #endif
 
 #if defined(MAGICKCORE_HEIC_DELEGATE)
@@ -358,6 +355,73 @@ static MagickBooleanType ReadHEICImageHandle(const ImageInfo *image_info,
     "heic:preserve-orientation"));
   if (preserve_orientation == MagickFalse)
     (void) SetImageProperty(image,"exif:Orientation","1",exception);
+  else
+    {
+#if LIBHEIF_NUMERIC_VERSION >= HEIC_COMPUTE_NUMERIC_VERSION(1,17,0)
+      heif_item_id
+        item_id;
+
+      heif_property_id
+        transforms[1];
+
+      int
+        count;
+
+      struct heif_context
+        *heif_context;
+
+      heif_context=heif_image_handle_get_context(image_handle);
+      item_id=heif_image_handle_get_item_id(image_handle);
+      count=heif_item_get_transformation_properties(heif_context,item_id,
+        transforms,1);
+      if (count == 1)
+        {
+          enum heif_transform_mirror_direction
+            mirror;
+
+          int
+            rotation_ccw;
+
+          mirror=heif_item_get_property_transform_mirror(heif_context,item_id,
+            transforms[0]);
+          rotation_ccw=heif_item_get_property_transform_rotation_ccw(
+            heif_context,item_id,transforms[0]);
+          switch(mirror)
+          {
+            case heif_transform_mirror_direction_horizontal:
+            {
+              if (rotation_ccw == 0)
+                image->orientation=TopRightOrientation;
+              else if (rotation_ccw == 270)
+                image->orientation=LeftTopOrientation;
+              break;
+            }
+            case heif_transform_mirror_direction_vertical:
+            {
+              if (rotation_ccw == 0)
+                image->orientation=BottomLeftOrientation;
+              else if (rotation_ccw == 270)
+                image->orientation=RightBottomOrientation;
+              break;
+            }
+            case heif_transform_mirror_direction_invalid:
+            {
+              if (rotation_ccw == 0)
+                image->orientation=TopLeftOrientation;
+              else if (rotation_ccw == 90)
+                image->orientation=LeftBottomOrientation;
+              else if (rotation_ccw == 180)
+                image->orientation=BottomRightOrientation;
+              else if (rotation_ccw == 270)
+                image->orientation=RightTopOrientation;
+              break;
+            }
+          }
+        }
+#endif
+      image->columns=(size_t) heif_image_handle_get_ispe_width(image_handle);
+      image->rows=(size_t) heif_image_handle_get_ispe_height(image_handle);
+    }
   if (ReadHEICColorProfile(image,image_handle,exception) == MagickFalse)
     return(MagickFalse);
   if (ReadHEICExifProfile(image,image_handle,exception) == MagickFalse)
